@@ -53,12 +53,14 @@ class DriverPool:
         self.chang_proxy_on_each_request = change_proxy_on_each_request
         self.proxies = proxies
         self.install_adblock = install_adblock
+        self.anticaptcha_api_key = anticaptcha_api_key
 
     def append_driver(self):
         driver = Driver(pool=self,
                         change_proxy_on_each_request=self.chang_proxy_on_each_request,
                         proxies=self.proxies,
-                        install_adblock=self.install_adblock)
+                        install_adblock=self.install_adblock,
+                        anticaptcha_api_key=self.anticaptcha_api_key)
         self.drivers.append(driver)
         return driver
 
